@@ -29,7 +29,7 @@ class Reporter:
 
     def _build_report(self, metrics):
         metric_to_list = lambda m: [
-            m.datetime.timestamp(),
+            round(m.datetime.timestamp()),
             round(m.value, 2),
             m.measurement,
             m.queue_name,
